==> haskell-scotty-0.12-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 scotty
version:              0.12
visibility:           public
id:                   scotty-0.12-L25GkHmoIF46D4vJvtQfNK
key:                  scotty-0.12-L25GkHmoIF46D4vJvtQfNK
license:              BSD-3-Clause
copyright:            (c) 2012-Present Andrew Farmer
maintainer:           Andrew Farmer <xichekolas@gmail.com>
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    import Data.Monoid (mconcat)

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- param &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  40ca1bc4b3e27232b7b855cd5e7fe38e
exposed:              True
exposed-modules:      Web.Scotty Web.Scotty.Internal.Types Web.Scotty.Trans
hidden-modules:       Web.Scotty.Action Web.Scotty.Route Web.Scotty.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/scotty-0.12
library-dirs:         /usr/lib/ghc-8.10.4/site-local/scotty-0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/scotty-0.12
hs-libraries:         HSscotty-0.12-L25GkHmoIF46D4vJvtQfNK
depends:
    aeson-1.5.6.0-5UhD0HeD84KFPVsjqEyp8O base-4.14.1.0
    base-compat-batteries-0.11.2-8VueMZGBBfCK2ESZB1FQrt
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L4eezPrloIkFfLdkfuDqXK
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 exceptions-0.10.4
    http-types-0.12.3-FO7KHA2u7UcAhh6pUwD9xg
    monad-control-1.0.2.3-37XqcEayPiFE3FudU6V7HO mtl-2.2.2
    network-3.1.2.1-w02zdyzpzZ9XPxmvyf1XO
    regex-compat-0.95.2.1-78EEG6TtwGx58mxanOnpSH text-1.2.4.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-71gNfOEizKQATb3gR7s3iS
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    wai-3.2.3-IAsnM61PN9gKx7TYUYrogW
    wai-extra-3.1.6-7bwCV2jRWhB5TpiUmkANBr
    warp-3.3.14-7EAlnMh4AOABXoDCxyQKJ

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-scotty-0.12-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-scotty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 scotty
version:              0.12
visibility:           public
id:                   scotty-0.12-KFZwCKe8aau14mwMUTVZiv
key:                  scotty-0.12-KFZwCKe8aau14mwMUTVZiv
license:              BSD-3-Clause
copyright:            (c) 2012-Present Andrew Farmer
maintainer:           Andrew Farmer <xichekolas@gmail.com>
author:               Andrew Farmer <xichekolas@gmail.com>
stability:            experimental
homepage:             https://github.com/scotty-web/scotty
synopsis:
    Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp

description:
    A Haskell web framework inspired by Ruby'\''s Sinatra, using WAI and Warp.

    @
    &#123;-&#35; LANGUAGE OverloadedStrings &#35;-&#125;

    import Web.Scotty

    import Data.Monoid (mconcat)

    main = scotty 3000 $
    &#32;&#32;get &#34;/:word&#34; $ do
    &#32;&#32;&#32;&#32;beam <- param &#34;word&#34;
    &#32;&#32;&#32;&#32;html $ mconcat [&#34;&#60;h1&#62;Scotty, &#34;, beam, &#34; me up!&#60;/h1&#62;&#34;]
    @


    Scotty is the cheap and cheerful way to write RESTful, declarative web applications.

    * A page is as simple as defining the verb, url pattern, and Text content.

    * It is template-language agnostic. Anything that returns a Text value will do.

    * Conforms to WAI Application interface.

    * Uses very fast Warp webserver by default.

    As for the name: Sinatra + Warp = Scotty.

    [WAI] <http://hackage.haskell.org/package/wai>

    [Warp] <http://hackage.haskell.org/package/warp>

category:             Web
abi:                  aae42e2ae586b3915539eb01c79a8b97
exposed:              True
exposed-modules:      Web.Scotty Web.Scotty.Internal.Types Web.Scotty.Trans
hidden-modules:       Web.Scotty.Action Web.Scotty.Route Web.Scotty.Util
import-dirs:          /usr/lib/ghc-8.10.4/site-local/scotty-0.12
library-dirs:         /usr/lib/ghc-8.10.4/site-local/scotty-0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/scotty-0.12
hs-libraries:         HSscotty-0.12-KFZwCKe8aau14mwMUTVZiv
depends:
    aeson-1.5.6.0-1F4wJcYByqDF2zyvzlYTcu base-4.14.1.0
    base-compat-batteries-0.11.2-ITTPYZFjlUu38NfaU2XIwM
    blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ bytestring-0.10.12.0
    case-insensitive-1.2.1.0-L4eezPrloIkFfLdkfuDqXK
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 exceptions-0.10.4
    http-types-0.12.3-InbfZWeQi3M22zAdmMehbV
    monad-control-1.0.2.3-D3WzclgXvrF9bXm8MK0HB6 mtl-2.2.2
    network-3.1.2.1-FyLZTSFnP6d8KABeD8iAHI
    regex-compat-0.95.2.1-78EEG6TtwGx58mxanOnpSH text-1.2.4.1
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KQkZCybzoHB5dQoSzDOalO
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM
    wai-3.2.3-K7nLw4wFq7T4ZSKv69iWlZ
    wai-extra-3.1.6-6jZrHrjsi4jCXafurei5UP
    warp-3.3.14-Fh63QQO9sQ471f8YW4U4BT

haddock-interfaces:   /usr/share/doc/haskell-scotty/html/scotty.haddock
haddock-html:         /usr/share/doc/haskell-scotty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
